@@ -12,25 +12,25 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
+ * You should have received a copy of the GNU Lesser General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef LIBMANETTE_VERSION_H
-#define LIBMANETTE_VERSION_H
+/**
+ * SECTION:manette-version
+ * @short_description: Version checking
+ * @title: Version
+ *
+ * libmanette provides macros to check the version of the library
+ * at compile-time.
+ */
+
+#pragma once
 
 #if !defined(__MANETTE_INSIDE__) && !defined(MANETTE_COMPILATION)
 # error "Only <libmanette.h> can be included directly."
 #endif
 
-/**
- * SECTION:libmanetteversion
- * @short_description: libmanette version checking
- *
- * libmanette provides macros to check the version of the library
- * at compile-time
- */
-
 /**
  * LIBMANETTE_MAJOR_VERSION:
  *
@@ -50,14 +50,14 @@
  *
  * libmanette micro version component (e.g. 3 if %LIBMANETTE_VERSION is 1.2.3)
  */
-#define LIBMANETTE_MICRO_VERSION (4)
+#define LIBMANETTE_MICRO_VERSION (6)
 
 /**
  * LIBMANETTE_VERSION
  *
  * libmanette version.
  */
-#define LIBMANETTE_VERSION (0.2.4)
+#define LIBMANETTE_VERSION (0.2.6)
 
 /**
  * LIBMANETTE_VERSION_S:
@@ -65,7 +65,7 @@
  * libmanette version, encoded as a string, useful for printing and
  * concatenation.
  */
-#define LIBMANETTE_VERSION_S "0.2.4"
+#define LIBMANETTE_VERSION_S "0.2.6"
 
 #define LIBMANETTE_ENCODE_VERSION(major,minor,micro) \
         ((major) << 24 | (minor) << 16 | (micro) << 8)
@@ -93,5 +93,3 @@
          (LIBMANETTE_MAJOR_VERSION == (major) && LIBMANETTE_MINOR_VERSION > (minor)) || \
          (LIBMANETTE_MAJOR_VERSION == (major) && LIBMANETTE_MINOR_VERSION == (minor) && \
           LIBMANETTE_MICRO_VERSION >= (micro)))
-
-#endif /* LIBMANETTE_VERSION_H */
